==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
export let ChartGroupDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartGroupDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartGroupDescriptionDescriptionMetadata.a == null) {
                ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
            }
            if (a.j(ChartGroupDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.y(ChartGroupDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            ChartSortDescriptionDescriptionMetadata.c(a);
        }
        static d(a) {
            ChartGroupDescriptionDescriptionMetadata.b(a);
            a.aa("ChartGroupDescription", () => new ChartGroupDescriptionDescription());
            a.z("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
        }
    }
    ChartGroupDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
export let ChartGroupDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartGroupDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartGroupDescriptionDescriptionMetadata.a == null) {
                ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
            }
            if (a.k(ChartGroupDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ChartGroupDescriptionDescriptionMetadata.a);
        }
        static c(a) {
            ChartSortDescriptionDescriptionMetadata.c(a);
        }
        static d(a) {
            ChartGroupDescriptionDescriptionMetadata.b(a);
            a.ac("ChartGroupDescription", () => new ChartGroupDescriptionDescription());
            a.ab("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
        }
    }
    ChartGroupDescriptionDescriptionMetadata.$t = /*@__PURE__*/ markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
})();
